pub trait TxCheck<'tx> {
// Required method
fn check(&self) -> Vec<String>;
}Expand description
Check performs several consistency checks on the database for this transaction. An error is returned if any inconsistency is found.
It can be safely run concurrently on a writable transaction. However, this incurs a high cost for large databases and databases with a lot of subbuckets because of caching. This overhead can be removed if running on a read-only transaction, however, it is not safe to execute other writer transactions at the same time.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".